@@ -85,7 +85,7 @@ qusage.single = function(eset,       ##a matrix of log2(expression values), with
   
   cat("Done.\nAggregating gene data for gene sets.")
   nu = floor(min(results$dof,na.rm=T))
-  if(nu<5){cat("\nLow sample size detected. Increasing n.points in aggregateGeneSet.")}
+  if(nu<5){cat("\nLow sample size detected. n.points should be increased for better accuracy.")}
   results = aggregateGeneSet(results, geneSets, silent=F, n.points=n.points)
   cat("Done.\nCalculating variance inflation factors...")
   results = calcVIF(eset, results)
@@ -693,10 +693,12 @@ compareTwoDistsFaster <-function(dens1=runif(256*8,0,1), dens2=runif(256*8,0,1),
 
 multi_conv<-function(x){
   x_fft<-apply(x,2,function(x)fft(x, inverse = FALSE))
+  # x_fft<-apply(x,2,function(x)fftw::FFT(x, inverse = FALSE))
   M<-max(Mod(x_fft))
   x_fft<-x_fft/M
   Prod_fft<-apply(x_fft,1,prod)
   p1<-Re(fft(Prod_fft,inverse=TRUE))
+  # p1<-Re(fftw::FFT(Prod_fft,inverse=TRUE))
   N<-nrow(x)
   #     if(ncol(x)%%2==0)p1<-c(p1[(N/2+1):N],p1[1:(N/2)])
   Mp1<-which.max(p1)
@@ -974,4 +976,4 @@ approximatedNu<-c(7.2144478,4.7860183,3.4886415,2.7484892,2.2968314,2.0029888,1.
 
 getExAbs<-function(Nu){
   approx(c(seq(1,10,0.1),seq(11,100,1),seq(110,1000,10)),approximatedNu,Nu)$y
-}
\ No newline at end of file
+}
